I took these two themes from here:
https://github.com/LeonWong0609/Typora-D42ker-Github-theme
and here:
https://github.com/typora/typora-default-themes

at the time, neither theme had any license associated with it. 